@@ -9,13 +9,14 @@ from ConfigParser import SafeConfigParser
 import dbus
 from dbus.mainloop.glib import DBusGMainLoop
 
-version = "2.1-1"
+version = "2.2-0"
 trackingEnabled = True
 stopTracking = True
 stopWhenIdle = False
 stopAfterMinutes = "5 minutes"
 confirmDisconnect = True
 showRestartButton = True
+showAllConnections = True
 showSettingsButton = True
 showConnected = True
 connectedIcon = "Symbol"
@@ -40,6 +41,7 @@ class Window(object):
         global wifiPMIcon
         global confirmDisconnect
         global showRestartButton
+        global showAllConnections
         global showSettingsButton
         global skipSystemCheck
         global autostart
@@ -73,6 +75,7 @@ class Window(object):
             self.parser.set('options', 'stopAfterMinutes', str(stopAfterMinutes))
             self.parser.set('options', 'confirmDisconnect', str(confirmDisconnect))
             self.parser.set('options', 'showRestartButton', str(showRestartButton))
+            self.parser.set('options', 'showAllConnections', str(showAllConnections))
             self.parser.set('options', 'showSettingsButton', str(showSettingsButton))
             self.parser.set('options', 'showConnected', str(showConnected))
             self.parser.set('options', 'connectedIcon', str(connectedIcon))
@@ -80,9 +83,14 @@ class Window(object):
             self.parser.set('options', 'skipSystemCheck', str(skipSystemCheck))
             self.parser.set('options', 'configReverseOrder', str(configReverseOrder))
             self.parser.set('options', 'configShowWifiHint', str(configShowWifiHint))
+            self.parser.set('wifipm', 'keepWifiPMOff', str(keepWifiPMOff))
+            self.parser.set('wifipm', 'toggleWifiPM', str(toggleWifiPM))
+            self.parser.set('wifipm', 'wifiPMOffSec', str(wifiPMOffSec))
+            self.parser.set('wifipm', 'wifiPMOnSec', str(wifiPMOnSec))
             self.parser.write(configFile)
             configFile.close()
         else:
+            configChanged = False
             self.parser.read('/home/user/.openssh-status-widget')
             if self.parser.has_section('options'):
                 if self.parser.has_option('options', 'trackingEnabled'):
@@ -109,6 +117,10 @@ class Window(object):
                     showRestartButton = self.parser.getboolean('options', 'showRestartButton')
                 else:
                     self.parser.set('options', 'showRestartButton', str(showRestartButton))
+                if self.parser.has_option('options', 'showAllConnections'):
+                    showAllConnections = self.parser.getboolean('options', 'showAllConnections')
+                else:
+                    self.parser.set('options', 'showAllConnections', str(showAllConnections))
                 if self.parser.has_option('options', 'showSettingsButton'):
                     showSettingsButton = self.parser.getboolean('options', 'showSettingsButton')
                 else:
@@ -121,7 +133,7 @@ class Window(object):
                     connectedIcon = self.parser.get('options', 'connectedIcon')
                 else:
                     self.parser.set('options', 'connectedIcon', str(connectedIcon))
-                if self.parser.has_option('options', 'wifiPMIcon'):
+                if self.parser.has_option('options', 'keepWifiPM'):
                     wifiPMIcon = self.parser.getboolean('options', 'wifiPMIcon')
                 else:
                     self.parser.set('options', 'wifiPMIcon', str(wifiPMIcon))
@@ -137,6 +149,33 @@ class Window(object):
                     configShowWifiHint = self.parser.getboolean('options', 'configShowWifiHint')
                 else:
                     self.parser.set('options', 'configShowWifiHint', str(configShowWifiHint))
+                    configChanged = True
+            if self.parser.has_section('wifipm'):
+                if self.parser.has_option('wifipm', 'keepWifiPMOff'):
+                    keepWifiPMOff = self.parser.getboolean('wifipm', 'keepWifiPMOff')
+                else:
+                    self.parser.set('wifipm', 'keepWifiPMOff', str(keepWifiPMOff))
+                if self.parser.has_option('wifipm', 'toggleWifiPM'):
+                    toggleWifiPM = self.parser.getboolean('wifipm', 'toggleWifiPM')
+                else:
+                    self.parser.set('wifipm', 'toggleWifiPM', str(toggleWifiPM))
+                if self.parser.has_option('wifipm', 'wifiPMOffSec'):
+                    wifiPMOffSec = self.parser.get('wifipm', 'wifiPMOffSec')
+                else:
+                    self.parser.set('wifipm', 'wifiPMOffSec', str(wifiPMOffSec))
+                if self.parser.has_option('wifipm', 'wifiPMOnSec'):
+                    wifiPMOnSec = self.parser.get('wifipm', 'wifiPMOnSec')
+                else:
+                    self.parser.set('wifipm', 'wifiPMOnSec', str(wifiPMOnSec))
+            else:
+                configChanged = True
+                self.parser.add_section('wifipm')
+                self.parser.set('wifipm', 'keepWifiPMOff', str(keepWifiPMOff))
+                self.parser.set('wifipm', 'toggleWifiPM', str(toggleWifiPM))
+                self.parser.set('wifipm', 'wifiPMOffSec', str(wifiPMOffSec))
+                self.parser.set('wifipm', 'wifiPMOnSec', str(wifiPMOnSec))
+            if configChanged:
+                self.write_config()
         
         if not path.isfile("/etc/event.d/sshd"):
             system("sudo openssh-status.sh create_sshd")
@@ -151,45 +190,6 @@ class Window(object):
         if not autostart and not autostartDisabled:
             system("sudo openssh-status.sh insert_start")
             
-        sshFile = open("/etc/ssh/sshd_config", 'r')
-        lines = sshFile.readlines()
-        sshFile.close()
-        for line in lines:
-            if line.strip('\n').strip(' ') == "ForceCommand /usr/lib/openssh/session":
-                keepWifiPMOffInstalled = True
-            else:
-                line = line.strip('\n').strip(' ')
-                if line[0:12] == "ForceCommand":
-                    otherForceCommand = True
-        if otherForceCommand:
-            system("sudo openssh-status.sh no_force")
-            keepWifiPMOffInstalled = False
-        if not keepWifiPMOffInstalled:
-            system("sudo openssh-status.sh insert_wifipm")
-            
-        sshFile = open("/usr/lib/openssh/session", 'r')
-        lines = sshFile.readlines()
-        sshFile.close()
-        for line in lines:
-            if line.strip('\n').strip(' ') == "#SSH_IP=\"disabled\"":
-                keepWifiPMOff = True
-        
-        sshFile = open("/usr/lib/openssh/wifi-power-management", 'r')
-        lines = sshFile.readlines()
-        sshFile.close()
-        for line in lines:
-            if line.strip('\n').strip(' ') == "iwconfig wlan0 power on #toggle":
-                toggleWifiPM = True
-            if "pmoff" in line:
-                wifiPMOffSec = line.strip('\n').strip(' ').split(' ')[1]
-                if wifiPMOffSec == "1":
-                    wifiPMOffSec += " second"
-                else:
-                    wifiPMOffSec += " seconds"
-            if "pmon" in line:
-                wifiPMOnSec = line.strip('\n').strip(' ').split(' ')[1] + " seconds"
-                break
-        
         self.indicatorList = []
         for f in listdir('/usr/share/icons/hicolor/18x18/hildon/'):
             if f[0:21] == "openssh-status_users_" and f <> "openssh-status_users_symbol.png" and f[-4:] ==".png":
@@ -253,9 +253,13 @@ class Window(object):
         self.buttonShowRestart.set_label("Show restart button")
         self.buttonShowRestart.set_alignment(0.08, 0.5)
     
+        self.buttonShowAllConnections = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+        self.buttonShowAllConnections.set_label("Show connections overview")
+        self.buttonShowAllConnections.set_alignment(0.093, 0.5)
+    
         self.buttonShowSettings = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
         self.buttonShowSettings.set_label("Show settings button")
-        self.buttonShowSettings.set_alignment(0.083, 0.5)
+        self.buttonShowSettings.set_alignment(0.082, 0.5)
     
         self.buttonShowConnected = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
         self.buttonShowConnected.set_label("Show status 'connected' in status area")
@@ -337,10 +341,12 @@ class Window(object):
         if confirmDisconnect:
             self.buttonConfirm.set_active(True)
             self.buttonShowRestart.set_sensitive(True)
+            self.buttonShowAllConnections.set_sensitive(True)
             self.buttonShowSettings.set_sensitive(True)
         else:
             self.buttonConfirm.set_active(False)
             self.buttonShowRestart.set_sensitive(False)
+            self.buttonShowAllConnections.set_sensitive(False)
             self.buttonShowSettings.set_sensitive(False)
 
         if showRestartButton:
@@ -348,6 +354,11 @@ class Window(object):
         else:
             self.buttonShowRestart.set_active(False)
 
+        if showAllConnections:
+            self.buttonShowAllConnections.set_active(True)
+        else:
+            self.buttonShowAllConnections.set_active(False)
+
         if showSettingsButton:
             self.buttonShowSettings.set_active(True)
         else:
@@ -374,6 +385,7 @@ class Window(object):
             self.buttonStopAfterMinutes.set_sensitive(False)
             self.buttonConfirm.set_sensitive(False)
             self.buttonShowRestart.set_sensitive(True)
+            self.buttonShowAllConnections.set_sensitive(True)
             self.buttonShowSettings.set_sensitive(True)
             self.buttonShowConnected.set_sensitive(False)
             self.buttonConnectedIcon.set_sensitive(False)
@@ -405,6 +417,7 @@ class Window(object):
         self.buttonStopAfterMinutes.connect("value-changed", self.buttonStopAfterMinutes_changed)
         self.buttonConfirm.connect("clicked", self.buttonConfirm_clicked)
         self.buttonShowRestart.connect("clicked", self.buttonShowRestart_clicked)
+        self.buttonShowAllConnections.connect("clicked", self.buttonShowAllConnections_clicked)
         self.buttonShowSettings.connect("clicked", self.buttonShowSettings_clicked)
         self.buttonShowConnected.connect("clicked", self.buttonShowConnected_clicked)
         self.buttonConnectedIcon.connect("value-changed", self.buttonConnectedIcon_changed)
@@ -429,6 +442,7 @@ class Window(object):
         self.vbox.pack_start(self.buttonShowConnected, False, False, 0)
         self.vbox.pack_start(self.buttonConnectedIcon, False, False, 0)
         self.vbox.pack_start(self.buttonConfirm, False, False, 0)
+        self.vbox.pack_start(self.buttonShowAllConnections, False, False, 0)
         self.vbox.pack_start(self.buttonShowRestart, False, False, 0)
         self.vbox.pack_start(self.buttonShowSettings, False, False, 0)
         self.vbox.pack_start(self.buttonWifiPMIcon, False, False, 0)
@@ -453,6 +467,7 @@ class Window(object):
         self.vbox.remove(self.buttonShowConnected)
         self.vbox.remove(self.buttonConnectedIcon)
         self.vbox.remove(self.buttonConfirm)
+        self.vbox.remove(self.buttonShowAllConnections)
         self.vbox.remove(self.buttonShowRestart)
         self.vbox.remove(self.buttonShowSettings)
         self.vbox.remove(self.buttonWifiPMIcon)
@@ -481,9 +496,11 @@ class Window(object):
             self.buttonConfirm.set_sensitive(True)
             if confirmDisconnect:
                 self.buttonShowRestart.set_sensitive(True)
+                self.buttonShowAllConnections.set_sensitive(True)
                 self.buttonShowSettings.set_sensitive(True)
             else:
                 self.buttonShowRestart.set_sensitive(False)
+                self.buttonShowAllConnections.set_sensitive(False)
                 self.buttonShowSettings.set_sensitive(False)
             self.buttonShowConnected.set_sensitive(True)
             if showConnected:
@@ -494,6 +511,7 @@ class Window(object):
             self.buttonStopAfterMinutes.set_sensitive(False)
             self.buttonConfirm.set_sensitive(False)
             self.buttonShowRestart.set_sensitive(True)
+            self.buttonShowAllConnections.set_sensitive(True)
             self.buttonShowSettings.set_sensitive(True)
             self.buttonShowConnected.set_sensitive(False)
             self.buttonConnectedIcon.set_sensitive(False)
@@ -536,9 +554,11 @@ class Window(object):
         confirmDisconnect = not confirmDisconnect
         if confirmDisconnect:
             self.buttonShowRestart.set_sensitive(True)
+            self.buttonShowAllConnections.set_sensitive(True)
             self.buttonShowSettings.set_sensitive(True)
         else:
             self.buttonShowRestart.set_sensitive(False)
+            self.buttonShowAllConnections.set_sensitive(False)
             self.buttonShowSettings.set_sensitive(False)
             if showSettingsButton:
                 self.printDialog("Settings can be accessed by opening 'OSW Options' in the application menu, category desktop.")
@@ -553,6 +573,13 @@ class Window(object):
         self.write_config()
         system("dbus-send --type=signal / org.maemo.oswoptions.changed1 string:'showRestartButton' string:'"+str(showRestartButton)+"'")
 
+    def buttonShowAllConnections_clicked(self, dummy):
+        global showAllConnections
+        showAllConnections = not showAllConnections
+        self.parser.set('options', 'showAllConnections', str(showAllConnections))
+        self.write_config()
+        system("dbus-send --type=signal / org.maemo.oswoptions.changed1 string:'showAllConnections' string:'"+str(showAllConnections)+"'")
+
     def buttonShowSettings_clicked(self, dummy):
         global showSettingsButton
         showSettingsButton = not showSettingsButton
@@ -621,6 +648,8 @@ class Window(object):
             self.buttonWifiPMOffSec.set_sensitive(False)
             self.buttonWifiPMOnSec.set_sensitive(False)
             system("sudo openssh-status.sh disable_wifipmoff")
+        self.parser.set('wifipm', 'keepWifiPMOff', str(keepWifiPMOff))
+        self.write_config()
         system("dbus-send --type=signal / org.maemo.oswoptions.changed1 string:'keepWifiPMOff' string:'"+str(keepWifiPMOff)+"'")
     
     def buttonKeepWifiPMOff_dbus(self):
@@ -641,14 +670,14 @@ class Window(object):
             self.buttonWifiPMOffSec.set_sensitive(False)
             self.buttonWifiPMOnSec.set_sensitive(False)
         self.buttonKeepWifiPMOff.handler_unblock(self.buttonKeepWifiPMOff_id)
+        self.parser.set('wifipm', 'keepWifiPMOff', str(keepWifiPMOff))
     
     def buttonToggleWifiPM_clicked(self, dummy):
         global toggleWifiPM
         toggleWifiPM = not toggleWifiPM
-        if toggleWifiPM:
-            system("sudo openssh-status.sh enable_togglepm")
-        else:
-            system("sudo openssh-status.sh disable_togglepm")
+        self.parser.set('wifipm', 'toggleWifiPM', str(toggleWifiPM))
+        self.write_config()
+        system("sudo openssh-status.sh togglepm_changed")
         system("dbus-send --type=signal / org.maemo.oswoptions.changed1 string:'toggleWifiPM' string:'"+str(toggleWifiPM)+"'")
         
     def buttonToggleWifiPM_dbus(self):
@@ -660,6 +689,7 @@ class Window(object):
         else:
             self.buttonToggleWifiPM.set_active(False)
         self.buttonToggleWifiPM.handler_unblock(self.buttonToggleWifiPM_id)
+        self.parser.set('wifipm', 'toggleWifiPM', str(toggleWifiPM))
         
     def selectWifiPMOffSec(self):
         selector = hildon.TouchSelector(text = True)
@@ -669,8 +699,10 @@ class Window(object):
         
     def buttonWifiPMOffSec_changed(self, dummy):
         t = self.buttonWifiPMOffSec.get_value()
-        system("sudo openssh-status.sh set_pmoffsec "+t.split(' ')[0])
-        system("dbus-send --type=signal / org.maemo.oswoptions.changed1 string:'wifiPMOffSec' string:'"+str(t)+"'")
+        self.parser.set('wifipm', 'wifiPMOffSec', t)
+        self.write_config()
+        system("sudo openssh-status.sh togglepm_changed")
+        system("dbus-send --type=signal / org.maemo.oswoptions.changed1 string:'wifiPMOffSec' string:'"+t+"'")
         
     def buttonWifiPMOffSec_dbus(self, val):
         self.buttonWifiPMOffSec.handler_block(self.buttonWifiPMOffSec_id)
@@ -679,6 +711,7 @@ class Window(object):
         except:
             pass
         self.buttonWifiPMOffSec.handler_unblock(self.buttonWifiPMOffSec_id)
+        self.parser.set('wifipm', 'wifiPMOffSec', val)
         
     def selectWifiPMOnSec(self):
         selector = hildon.TouchSelector(text = True)
@@ -688,8 +721,10 @@ class Window(object):
         
     def buttonWifiPMOnSec_changed(self, dummy):
         t = self.buttonWifiPMOnSec.get_value()
-        system("sudo openssh-status.sh set_pmonsec "+t.split(' ')[0])
-        system("dbus-send --type=signal / org.maemo.oswoptions.changed1 string:'wifiPMOnSec' string:'"+str(t)+"'")
+        self.parser.set('wifipm', 'wifiPMOnSec', t)
+        self.write_config()
+        system("sudo openssh-status.sh togglepm_changed")
+        system("dbus-send --type=signal / org.maemo.oswoptions.changed1 string:'wifiPMOnSec' string:'"+t+"'")
         
     def buttonWifiPMOnSec_dbus(self, val):
         self.buttonWifiPMOnSec.handler_block(self.buttonWifiPMOnSec_id)
@@ -698,6 +733,7 @@ class Window(object):
         except:
             pass
         self.buttonWifiPMOnSec.handler_unblock(self.buttonWifiPMOnSec_id)
+        self.parser.set('wifipm', 'wifiPMOnSec', val)
         
     def write_config(self):
         configFile = open('/home/user/.openssh-status-widget', 'r+')
@@ -735,6 +771,7 @@ class Window(object):
             self.pack_startWifiPMButtons()
         self.parser.set('options', 'configReverseOrder', str(configReverseOrder))
         self.write_config()
+        system("dbus-send --type=signal / org.maemo.oswoptions.changed1 string:'configReverseOrder' string:'"+str(configReverseOrder)+"'")
     
     def about_clicked(self, dummy):
         self.about = gtk.Dialog("Info", self.window)
