@@ -23,9 +23,10 @@ class opensshStatus(StatusMenuItem):
         self.trackingEnabled = True
         self.stopTracking = True
         self.stopWhenIdle = False
-        self.stopAfterMinutes = 5
+        self.stopAfterMinutes = "5 minutes"
         self.confirmDisconnect = True
         self.showRestartButton = True
+        self.showAllConnections = True
         self.showSettingsButton = True
         self.showConnected = True
         connectedIcon = "symbol"
@@ -34,6 +35,7 @@ class opensshStatus(StatusMenuItem):
         self.wifiPMOffSec = "2 seconds"
         self.wifiPMOnSec = "4 seconds"
         wifiPMIcon = True
+        self.showAllDialog = False
         self.skipSystemCheck = False
         configReverseOrder = False
         self.configShowWifiHint = True
@@ -54,9 +56,10 @@ class opensshStatus(StatusMenuItem):
             self.parser.set('options', 'trackingEnabled', str(self.trackingEnabled))
             self.parser.set('options', 'stopTracking', str(self.stopTracking))
             self.parser.set('options', 'stopWhenIdle', str(self.stopWhenIdle))
-            self.parser.set('options', 'stopAfterMinutes', str(self.stopAfterMinutes))
+            self.parser.set('options', 'stopAfterMinutes', str(self.stopAfterMinutes) + " minutes")
             self.parser.set('options', 'confirmDisconnect', str(self.confirmDisconnect))
             self.parser.set('options', 'showRestartButton', str(self.showRestartButton))
+            self.parser.set('options', 'showAllConnections', str(self.showAllConnections))
             self.parser.set('options', 'showSettingsButton', str(self.showSettingsButton))
             self.parser.set('options', 'showConnected', str(self.showConnected))
             self.parser.set('options', 'connectedIcon', str(connectedIcon))
@@ -64,9 +67,15 @@ class opensshStatus(StatusMenuItem):
             self.parser.set('options', 'skipSystemCheck', str(self.skipSystemCheck))
             self.parser.set('options', 'configReverseOrder', str(configReverseOrder))
             self.parser.set('options', 'configShowWifiHint', str(self.configShowWifiHint))
+            self.parser.add_section('wifipm')
+            self.parser.set('wifipm', 'keepWifiPMOff', str(self.keepWifiPMOff))
+            self.parser.set('wifipm', 'toggleWifiPM', str(self.toggleWifiPM))
+            self.parser.set('wifipm', 'wifiPMOffSec', str(self.wifiPMOffSec))
+            self.parser.set('wifipm', 'wifiPMOnSec', str(self.wifiPMOnSec))
             self.parser.write(configFile)
             configFile.close()
         else:
+            configChanged = False
             self.parser.read('/home/user/.openssh-status-widget')
             if self.parser.has_section('options'):
                 if self.parser.has_option('options', 'trackingEnabled'):
@@ -77,10 +86,14 @@ class opensshStatus(StatusMenuItem):
                     self.stopWhenIdle = self.parser.getboolean('options', 'stopWhenIdle')
                 if self.parser.has_option('options', 'stopAfterMinutes'):
                     self.stopAfterMinutes = int(self.parser.get('options', 'stopAfterMinutes').strip('_').split()[0]) # fix changed syntax when updating from < v1.6-0
+                else:
+                    self.stopAfterMinutes = int(self.stopAfterMinutes.split()[0])
                 if self.parser.has_option('options', 'confirmDisconnect'):
                     self.confirmDisconnect = self.parser.getboolean('options', 'confirmDisconnect')
                 if self.parser.has_option('options', 'showRestartButton'):
                     self.showRestartButton = self.parser.getboolean('options', 'showRestartButton')
+                if self.parser.has_option('options', 'showAllConnections'):
+                    self.showAllConnections = self.parser.getboolean('options', 'showAllConnections')
                 if self.parser.has_option('options', 'showSettingsButton'):
                     self.showSettingsButton = self.parser.getboolean('options', 'showSettingsButton')
                 if self.parser.has_option('options', 'showConnected'):
@@ -95,6 +108,25 @@ class opensshStatus(StatusMenuItem):
                     self.configShowWifiHint = self.parser.getboolean('options', 'configShowWifiHint')
                 else:
                     self.parser.set('options', 'configShowWifiHint', str(self.configShowWifiHint))
+                    configChanged = True
+            if self.parser.has_section('wifipm'):
+                if self.parser.has_option('wifipm', 'keepWifiPMOff'):
+                    self.keepWifiPMOff = self.parser.getboolean('wifipm', 'keepWifiPMOff')
+                if self.parser.has_option('wifipm', 'toggleWifiPM'):
+                    self.toggleWifiPM = self.parser.getboolean('wifipm', 'toggleWifiPM')
+                if self.parser.has_option('wifipm', 'wifiPMOffSec'):
+                    self.wifiPMOffSec = self.parser.get('wifipm', 'wifiPMOffSec')
+                if self.parser.has_option('wifipm', 'wifiPMOnSec'):
+                    self.wifiPMOnSec = self.parser.get('wifipm', 'wifiPMOnSec')
+            else:
+                configChanged = True
+                self.parser.add_section('wifipm')
+                self.parser.set('wifipm', 'keepWifiPMOff', str(self.keepWifiPMOff))
+                self.parser.set('wifipm', 'toggleWifiPM', str(self.toggleWifiPM))
+                self.parser.set('wifipm', 'wifiPMOffSec', str(self.wifiPMOffSec))
+                self.parser.set('wifipm', 'wifiPMOnSec', str(self.wifiPMOnSec))
+            if configChanged:
+                self.write_config()
         
         self.icon=gtk.gdk.pixbuf_new_from_file("/usr/share/icons/hicolor/18x18/hildon/openssh-status_no-users.png")
         try:
@@ -102,30 +134,6 @@ class opensshStatus(StatusMenuItem):
         except:
             self.icon_plus=gtk.gdk.pixbuf_new_from_file("/usr/share/icons/hicolor/18x18/hildon/openssh-status_users_symbol.png")
 
-        sshFile = open("/usr/lib/openssh/session", 'r')
-        lines = sshFile.readlines()
-        sshFile.close()
-        for line in lines:
-            if line.strip('\n').strip(' ') == "#SSH_IP=\"disabled\"":
-                self.keepWifiPMOff = True
-                break
-        
-        sshFile = open("/usr/lib/openssh/wifi-power-management", 'r')
-        lines = sshFile.readlines()
-        sshFile.close()
-        for line in lines:
-            if line.strip('\n').strip(' ') == "iwconfig wlan0 power on #toggle":
-                self.toggleWifiPM = True
-            if "pmoff" in line:
-                self.wifiPMOffSec = line.strip('\n').strip(' ').split(' ')[1]
-                if self.wifiPMOffSec == "1":
-                    self.wifiPMOffSec += " second"
-                else:
-                    self.wifiPMOffSec += " seconds"
-            if "pmon" in line:
-                self.wifiPMOnSec = line.strip('\n').strip(' ').split(' ')[1] + " seconds"
-                break
-                
         self.button=hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
         self.button.set_style(hildon.BUTTON_STYLE_PICKER)
         self.button.set_alignment(0.2,0.5,1,1)
@@ -198,6 +206,7 @@ class opensshStatus(StatusMenuItem):
                 self.trackingEnabled = True
             else:
                 self.trackingEnabled = False
+            self.parser.set('options', 'trackingEnabled', val)
             self.start()
                 
         
@@ -210,6 +219,7 @@ class opensshStatus(StatusMenuItem):
                     self.refresh = True
                     self.loopCount = -1
                     gobject.timeout_add(5000, self.sshTracker)
+            self.parser.set('options', 'stopTracking', val)
         
         if param == "stopWhenIdle":
             self.waitWhileIdle = False
@@ -217,27 +227,39 @@ class opensshStatus(StatusMenuItem):
                 self.stopWhenIdle = True
             else:
                 self.stopWhenIdle = False
+            self.parser.set('options', 'stopWhenIdle', val)
         
         if param == "stopAfterMinutes":
             self.stopAfterMinutes = int(val.strip('_').split()[0])
+            self.parser.set('options', 'stopAfterMinutes', val)
         
         if param == "confirmDisconnect":
             if val == "True":
                 self.confirmDisconnect = True
             else:
                 self.confirmDisconnect = False
+            self.parser.set('options', 'confirmDisconnect', val)
         
         if param == "showRestartButton":
             if val == "True":
                 self.showRestartButton = True
             else:
                 self.showRestartButton = False
+            self.parser.set('options', 'showRestartButton', val)
+        
+        if param == "showAllConnections":
+            if val == "True":
+                self.showAllConnections = True
+            else:
+                self.showAllConnections = False
+            self.parser.set('options', 'showAllConnections', val)
         
         if param == "showSettingsButton":
             if val == "True":
                 self.showSettingsButton = True
             else:
                 self.showSettingsButton = False
+            self.parser.set('options', 'showSettingsButton', val)
         
         if param == "showConnected":
             if val == "True":
@@ -255,6 +277,7 @@ class opensshStatus(StatusMenuItem):
                     self.set_status_area_icon(None)
                 self.connected = False
                 self.showConnected = False                
+            self.parser.set('options', 'showConnected', val)
         
         if param == "connectedIcon":
             try:
@@ -264,12 +287,17 @@ class opensshStatus(StatusMenuItem):
             if self.sshConnected:
                 self.connected = True
                 self.set_status_area_icon(self.icon_plus)
+            self.parser.set('options', 'connectedIcon', val)
         
         if param == "wifiPMIcon":
             if val == "True":
                 self.button2.show()
             else:
                 self.button2.hide()
+            self.parser.set('options', 'wifiPMIcon', val)
+        
+        if param == "configReverseOrder":
+            self.parser.set('options', 'configReverseOrder', val)
         
         if param == "keepWifiPMOff":
             if val == "True":
@@ -281,6 +309,7 @@ class opensshStatus(StatusMenuItem):
             else:
                 self.keepWifiPMOff = False
                 self.button2.set_image(self.image_wifi_pm_on)
+            self.parser.set('wifipm', 'keepWifiPMOff', val)
         
         if param == "toggleWifiPM":
             if val == "True":
@@ -289,12 +318,15 @@ class opensshStatus(StatusMenuItem):
             else:
                 self.toggleWifiPM = False
                 self.button2.set_image(self.image_wifi_pm_off)
+            self.parser.set('wifipm', 'toggleWifiPM', val)
         
         if param == "wifiPMOffSec":
             self.wifiPMOffSec = val
+            self.parser.set('wifipm', 'wifiPMOffSec', val)
     
         if param == "wifiPMOnSec":
             self.wifiPMOnSec = val
+            self.parser.set('wifipm', 'wifiPMOnSec', val)
     
     def handleDisplay(self, displayStatus):
         if displayStatus == "on" or displayStatus == "dimmed":
@@ -428,7 +460,46 @@ class opensshStatus(StatusMenuItem):
         self.sshRunning = int(getoutput("ps aux | grep -c /usr/sbin/sshd")) - 2
         
     def sshUsers(self):
-        self.sshConnected = int(getoutput("ps aux | grep sshd: | grep -c @")) - 1
+        self.sshConnected = int(getoutput("netstat -t | grep -c :ssh[[:space:]]*[0-9].*ESTABLISHED"))
+        
+    def sshAllUsers(self):
+        sshNetstat = " ".join(getoutput("netstat -t | grep :ssh.*ESTABLISHED").split()).split()
+        
+        countAllWLAN = 0
+        for element in sshNetstat:
+            if self.wlanIP in element:
+                countAllWLAN += 1
+        countInWLAN = 0
+        for element in sshNetstat:
+            if self.wlanIP + ":ssh" in element:
+                countInWLAN += 1
+        countOutWLAN = countAllWLAN - countInWLAN
+        
+        countAllUSB = 0
+        for element in sshNetstat:
+            if self.usbIP in element:
+                countAllUSB += 1
+        countInUSB = 0
+        for element in sshNetstat:
+            if self.usbIP + ":ssh" in element:
+                countInUSB += 1
+        countOutUSB = countAllUSB - countInUSB
+        
+        self.sshConnected = countInWLAN + countInUSB
+        
+        if countInWLAN != self.labelCountInWLAN:
+            self.labelCountInWLAN = countInWLAN
+            self.labelInWLAN.set_label(str(countInWLAN) + "  WLAN")
+        if countInUSB != self.labelCountInUSB:
+            self.labelCountInUSB = countInUSB
+            self.labelInUSB.set_label(str(countInUSB) + "  USB")
+        if countOutWLAN != self.labelCountOutWLAN:
+            self.labelCountOutWLAN = countOutWLAN
+            self.labelOutWLAN.set_label(str(countOutWLAN) + "  WLAN")
+        if countOutUSB != self.labelCountOutUSB:
+            self.labelCountOutUSB = countOutUSB
+            self.labelOutUSB.set_label(str(countOutUSB) + "  USB")
+    
         
     def sshTracker(self):
         if self.trackingEnabled:
@@ -439,7 +510,10 @@ class opensshStatus(StatusMenuItem):
             # Tracker
             if not self.loopCount or self.sshJustOff:
                 self.sshStatus()
-                self.sshUsers()
+                if not self.showAllDialog:
+                    self.sshUsers()
+                else:
+                    self.sshAllUsers()
                 if self.sshRunning and self.sshJustOff:
                     self.sshJustOff = 0
                 # Update on external server status change
@@ -536,34 +610,20 @@ class opensshStatus(StatusMenuItem):
         
     def button2Clicked(self, dummy):
         self.get_toplevel().hide()
-        system("sudo openssh-status.sh wifipmoff_once")
         
-        #self.sshUsers()
-        if int(getoutput("ps aux | grep ssh | grep -v grep | grep -c @")) == 0:
-            self.printInfo("Wifi PM is kept off for 30 sec.\nGood time to log in...")
-        else:
-            keepWifiPMOff = False
-            toggleWifiPM = False
-            sshFile = open("/usr/lib/openssh/session", 'r')
-            lines = sshFile.readlines()
-            sshFile.close()
-            for line in lines:
-                if line.strip('\n').strip(' ') == "#SSH_IP=\"disabled\"":
-                    keepWifiPMOff = True
-                    break
-            
-            sshFile = open("/usr/lib/openssh/wifi-power-management", 'r')
-            lines = sshFile.readlines()
-            sshFile.close()
-            for line in lines:
-                if line.strip('\n').strip(' ') == "iwconfig wlan0 power on #toggle":
-                    toggleWifiPM = True
-                    break
-            
-            if keepWifiPMOff == True and toggleWifiPM == False:
-                self.printInfo("Wifi PM is off anyway.\nNo need to keep it off for 30 sec.")
+        wlanIP = getoutput("/sbin/ifconfig wlan0 | grep 'inet addr:'").strip().split(' ')[1].replace('addr:','')
+        if  not int(getoutput("netstat -t | grep :ssh.*ESTABLISHED | grep -c " + wlanIP)):
+            self.printInfo("Wifi PM is kept off for 30 sec.\nGood time to connect...", 7)
+            system("sudo openssh-status.sh wifipmoff_once")
+        elif int(getoutput("ps aux | grep -v grep  | grep -c /usr/sbin/osw-power-management")):
+            if self.keepWifiPMOff == True and self.toggleWifiPM == False:
+                self.printInfo("Wifi PM is off anyway.\nNo need to keep it off for 30 sec.", 7)
             else:
-                self.printInfo("Wifi PM is kept off for 30 sec.\nGood time to log in...")
+                self.printInfo("Wifi PM is kept off for 30 sec.\nGood time to connect...", 7)
+                system("sudo openssh-status.sh wifipmoff_once")
+        else:
+            self.printInfo("Wifi PM is kept off for 30 sec.\nGood time to connect...", 7)
+            system("sudo openssh-status.sh wifipmoff_once")
 
     def button2Pressed(self, dummy):
         self.get_toplevel().hide()        
@@ -649,16 +709,19 @@ class opensshStatus(StatusMenuItem):
             self.buttonWifiPMOnSec.set_sensitive(False)
             self.button2.set_image(self.image_wifi_pm_on)
             system("sudo openssh-status.sh disable_wifipmoff")
+        self.parser.set('wifipm', 'keepWifiPMOff', str(self.keepWifiPMOff))
+        self.write_config()
         system("dbus-send --type=signal / org.maemo.oswoptions.changed2 string:'keepWifiPMOff' string:'dummy'")
         
     def buttonToggleWifiPM_clicked(self, dummy):
         self.toggleWifiPM = not self.toggleWifiPM
         if self.toggleWifiPM:
             self.button2.set_image(self.image_wifi_pm_toggle)
-            system("sudo openssh-status.sh enable_togglepm")
         else:
             self.button2.set_image(self.image_wifi_pm_off)
-            system("sudo openssh-status.sh disable_togglepm")
+        self.parser.set('wifipm', 'toggleWifiPM', str(self.toggleWifiPM))
+        self.write_config()
+        system("sudo openssh-status.sh togglepm_changed")
         system("dbus-send --type=signal / org.maemo.oswoptions.changed2 string:'toggleWifiPM' string:'dummy'")
         
     def selectWifiPMOffSec(self):
@@ -670,7 +733,9 @@ class opensshStatus(StatusMenuItem):
     def buttonWifiPMOffSec_changed(self, dummy):
         t = self.buttonWifiPMOffSec.get_value()
         self.wifiPMOffSec = t
-        system("sudo openssh-status.sh set_pmoffsec "+t.split(' ')[0])
+        self.parser.set('wifipm', 'wifiPMOffSec', t)
+        self.write_config()
+        system("sudo openssh-status.sh togglepm_changed")
         system("dbus-send --type=signal / org.maemo.oswoptions.changed2 string:'wifiPMOffSec' string:'"+t+"'")
         
     def selectWifiPMOnSec(self):
@@ -682,7 +747,9 @@ class opensshStatus(StatusMenuItem):
     def buttonWifiPMOnSec_changed(self, dummy):
         t = self.buttonWifiPMOnSec.get_value()
         self.wifiPMOnSec = t
-        system("sudo openssh-status.sh set_pmonsec "+t.split(' ')[0])
+        self.parser.set('wifipm', 'wifiPMOnSec', t)
+        self.write_config()
+        system("sudo openssh-status.sh togglepm_changed")
         system("dbus-send --type=signal / org.maemo.oswoptions.changed2 string:'wifiPMOnSec' string:'"+t+"'")
         
     def write_config(self):
@@ -794,29 +861,124 @@ class opensshStatus(StatusMenuItem):
         self.button.get_toplevel().hide()
         self.sshStatus()
         self.sshUsers()
+        
         if self.confirmDisconnect or not self.trackingEnabled:
+            
             self.dialog = gtk.Dialog("OpenSSH status", None)
-            if not self.showRestartButton:
-                buttonDisconnectStop = hildon.Button(gtk.HILDON_SIZE_THUMB_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-                buttonDisconnectStop.set_label('Disconnect and stop server')
-            else:
-                buttonDisconnectStop = hildon.Button(gtk.HILDON_SIZE_HALFSCREEN_WIDTH | gtk.HILDON_SIZE_THUMB_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-                buttonDisconnectStop.set_label('Disconnect\nStop server')
-                buttonDisconnectRestart = hildon.Button(gtk.HILDON_SIZE_HALFSCREEN_WIDTH | gtk.HILDON_SIZE_THUMB_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-                buttonDisconnectRestart.set_label('  Disconnect\nRestart server')
-            if not self.trackingEnabled:
-                buttonConnected = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-                buttonConnected.set_label('Server connections')
-                if self.sshConnected == 1:
-                    self.printInfo("1 connection")
-                else:
-                    self.printInfo(str(self.sshConnected)+" connections")
+            self.dialog.connect("destroy", self.dialogClosed)
             vbox2 = gtk.VBox(False,2)
             vbox2.set_border_width(8)
-            hbox = gtk.HBox(False,0)
-            if not self.trackingEnabled:
+            
+            if self.showAllConnections:
+                try:
+                    self.wlanIP = getoutput("/sbin/ifconfig wlan0 | grep 'inet addr:'").strip().split()[1].replace('addr:','')
+                except:
+                    self.wlanIP = "None"
+                try:
+                    self.usbIP = getoutput("/sbin/ifconfig usb0 | grep 'inet addr:'").strip().split()[1].replace('addr:','')
+                except:
+                    self.usbIP = "None"
+                
+                labelIn = gtk.Label("Server connections:")
+                labelOut = gtk.Label("Client connections:")
+                
+                self.labelInWLAN = gtk.Label("0  WLAN")
+                self.labelInWLAN.set_alignment(1, 0)
+                self.labelInUSB = gtk.Label("0  USB")
+                self.labelInUSB.set_alignment(1, 0)
+                self.labelOutWLAN = gtk.Label("0  WLAN")
+                self.labelOutWLAN.set_alignment(1, 0)
+                self.labelOutUSB = gtk.Label("0  USB")
+                self.labelOutUSB.set_alignment(1, 0)
+                
+                if self.trackingEnabled:
+                    self.showAllDialog = True
+                
+                    labelIn.set_alignment(1, 0)
+                    labelOut.set_alignment(1, 0)
+                
+                    hboxConnections = gtk.HBox(True, 32)
+                    vboxLabel1 = gtk.VBox(False, 0)
+                    vboxLabel2 = gtk.VBox(False, 0)
+                    vboxLabel3 = gtk.VBox(False, 0)
+                    vboxLabel1.pack_start(labelIn, False, False, 0)
+                    vboxLabel1.pack_start(labelOut, False, False, 0)
+                    vboxLabel2.pack_start(self.labelInWLAN, False, False, 0)
+                    vboxLabel2.pack_start(self.labelOutWLAN, False, False, 0)
+                    vboxLabel3.pack_start(self.labelInUSB, False, False, 0)
+                    vboxLabel3.pack_start(self.labelOutUSB, False, False, 0)
+                    spacerLabel = gtk.Label()
+                    hboxLabel23 = gtk.HBox(False, 0)
+                    hboxLabel23.pack_start(vboxLabel2, False, False, 0)
+                    hboxLabel23.pack_start(vboxLabel3, False, False, 32)
+                    hboxLabel23.pack_start(spacerLabel, True, True, 0)
+                    hboxConnections.pack_start(vboxLabel1, True, True, 0)
+                    hboxConnections.pack_start(hboxLabel23, True, True, 0)
+                    spaceLeftLabel = gtk.Label()
+                    spaceRightLabel = gtk.Label()
+                    hbox123 = gtk.HBox(False, 0)
+                    hbox123.pack_start(spaceLeftLabel, False, False, 0)
+                    hbox123.pack_start(hboxConnections, True, True, 0)
+                    hbox123.pack_start(spaceRightLabel, False, False, 0)
+                
+                else:
+                    labelIn.set_alignment(0, 0)
+                    labelOut.set_alignment(0, 0)
+                
+                    vboxLabel1 = gtk.VBox(False, 0)
+                    vboxLabel2 = gtk.VBox(False, 0)
+                    vboxLabel3 = gtk.VBox(False, 0)
+                    vboxLabel1.pack_start(labelIn, False, False, 0)
+                    vboxLabel1.pack_start(labelOut, False, False, 0)
+                    vboxLabel2.pack_start(self.labelInWLAN, False, False, 0)
+                    vboxLabel2.pack_start(self.labelOutWLAN, False, False, 0)
+                    vboxLabel3.pack_start(self.labelInUSB, False, False, 0)
+                    vboxLabel3.pack_start(self.labelOutUSB, False, False, 0)
+                    refreshButton = hildon.GtkButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+                    refreshButton.set_label("Refresh")
+                    hboxConnections = gtk.HBox(False, 60)
+                    hboxConnections.pack_start(vboxLabel1, False, False, 0)
+                    hboxConnections.pack_start(vboxLabel2, False, False, 0)
+                    hboxConnections.pack_start(vboxLabel3, False, False, 0)
+                    hboxConnections.pack_start(refreshButton, True, True, 0)
+                    spaceLeftLabel = gtk.Label()
+                    spaceRightLabel = gtk.Label()
+                    hbox123 = gtk.HBox(False, 0)
+                    hbox123.pack_start(spaceLeftLabel, False, False, 6)
+                    hbox123.pack_start(hboxConnections, True, True, 0)
+                    hbox123.pack_start(spaceRightLabel, False, False, 0)
+                    refreshButton.connect("clicked", self.sshCountAll)
+                
+                vbox2.pack_start(hbox123, False, False, 6)
+                
+                self.sshCountAll(0)
+            
+            if not self.showRestartButton:
+                buttonDisconnectStop = hildon.Button(gtk.HILDON_SIZE_THUMB_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+                if self.showAllConnections:
+                    buttonDisconnectStop.set_label('Server:  Disconnect and stop')
+                else:
+                    buttonDisconnectStop.set_label('Disconnect and stop server')
+            else:
+                buttonDisconnectStop = hildon.Button(gtk.HILDON_SIZE_HALFSCREEN_WIDTH | gtk.HILDON_SIZE_THUMB_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+                buttonDisconnectRestart = hildon.Button(gtk.HILDON_SIZE_HALFSCREEN_WIDTH | gtk.HILDON_SIZE_THUMB_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+                if self.showAllConnections:
+                    buttonDisconnectStop.set_label('            Server:\nDisconnect and stop')
+                    buttonDisconnectRestart.set_label('             Server:\nDisconnect and restart')
+                else:
+                    buttonDisconnectStop.set_label('Disconnect\nStop server')
+                    buttonDisconnectRestart.set_label('  Disconnect\nRestart server')
+            if not self.trackingEnabled and not self.showAllConnections:
+                buttonConnected = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+                buttonConnected.set_label('Server connections')
                 vbox2.pack_start(buttonConnected)
                 buttonConnected.connect("clicked", self.buttonConnected_clicked)
+                if self.sshConnected == 1:
+                    self.printInfo("1 connection", 2)
+                else:
+                    self.printInfo(str(self.sshConnected)+" connections", 2)
+            
+            hbox = gtk.HBox(False,0)
             hbox.pack_start(buttonDisconnectStop)
             if self.showRestartButton:
                 hbox.pack_start(buttonDisconnectRestart)
@@ -836,8 +998,43 @@ class opensshStatus(StatusMenuItem):
             self.sshDisconnect()
         else:
             time.sleep(1)
-            self.printInfo("OpenSSH Server not running!")
+            self.printInfo("OpenSSH Server not running!", 7)
+            
+    def dialogClosed(self, dummy):
+        self.showAllDialog = False
+            
+    def sshCountAll(self, dummy):
+        sshNetstat = " ".join(getoutput("netstat -t | grep :ssh.*ESTABLISHED").split()).split()
         
+        countAllWLAN = 0
+        for element in sshNetstat:
+            if self.wlanIP in element:
+                countAllWLAN += 1
+        countInWLAN = 0
+        for element in sshNetstat:
+            if self.wlanIP + ":ssh" in element:
+                countInWLAN += 1
+        countOutWLAN = countAllWLAN - countInWLAN
+        self.labelCountInWLAN = countInWLAN
+        self.labelCountOutWLAN = countOutWLAN
+        
+        countAllUSB = 0
+        for element in sshNetstat:
+            if self.usbIP in element:
+                countAllUSB += 1
+        countInUSB = 0
+        for element in sshNetstat:
+            if self.usbIP + ":ssh" in element:
+                countInUSB += 1
+        countOutUSB = countAllUSB - countInUSB
+        self.labelCountInUSB = countInUSB
+        self.labelCountOutUSB = countOutUSB
+        
+        self.labelInWLAN.set_label(str(countInWLAN) + "  WLAN")
+        self.labelInUSB.set_label(str(countInUSB) + "  USB")
+        self.labelOutWLAN.set_label(str(countOutWLAN) + "  WLAN")
+        self.labelOutUSB.set_label(str(countOutUSB) + "  USB")
+    
     def buttonSettings_clicked(self, dummy):
         self.dialog.destroy()
         if int(getoutput("ps aux | grep -v grep | grep -c /usr/bin/openssh-status-config.py")):
@@ -856,9 +1053,9 @@ class opensshStatus(StatusMenuItem):
     def buttonConnected_clicked(self, dummy):
         self.sshUsers()
         if self.sshConnected == 1:
-            self.printInfo("1 connection")
+            self.printInfo("1 connection", 2)
         else:
-            self.printInfo(str(self.sshConnected)+" connections")
+            self.printInfo(str(self.sshConnected)+" connections", 2)
     
     def sshDisconnect(self):
         self.sshStatus()
@@ -946,10 +1143,8 @@ class opensshStatus(StatusMenuItem):
         /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog \
         string:\""+msg+"\" uint32:0 string:")
 
-    def printInfo(self, msg):
-        system("run-standalone.sh dbus-send \
-        --type=method_call --dest=org.freedesktop.Notifications \
-        /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
-        string:\""+msg+"\"")
+    def printInfo(self, msg, sec):
+        banner = hildon.hildon_banner_show_information_with_markup(self.button, "no_icon", msg)
+        banner.set_timeout(sec * 1000) 
 
 hd_plugin_type = opensshStatus
